@@ -29,9 +29,7 @@
 #endif
 
 #include <nice/agent.h>
-#if HAVE_GIO_GIO_H
-#include <gio/gio.h>
-#endif
+#include <glib.h>
 
 #define ICE_SUCCESS 0
 #define ICE_FAILURE -1
